@@ -26,10 +26,7 @@ ThemeComboBox::ThemeComboBox(QWidget *parent)
     }
 }
 
-ThemeComboBox::~ThemeComboBox()
-{
-    delete d;
-}
+ThemeComboBox::~ThemeComboBox() = default;
 
 QString ThemeComboBox::currentTheme() const
 {
@@ -38,7 +35,7 @@ QString ThemeComboBox::currentTheme() const
 
 void ThemeComboBox::writeDefaultConfig() const
 {
-    KConfigGroup group(MessageListSettings::self()->config(), "MessageListView::StorageModelThemes");
+    KConfigGroup group(MessageListSettings::self()->config(), QStringLiteral("MessageListView::StorageModelThemes"));
 
     const QString themeID = currentTheme();
     group.writeEntry(QStringLiteral("DefaultSet"), themeID);
