@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2017 Volker Krause <vkrause@kde.org>
+  SPDX-FileCopyrightText: 2017 Volker Krause <vkrause@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "bodypartformatterfactory.h"
@@ -59,9 +46,11 @@ private Q_SLOTS:
         QVERIFY(application_octet_stream_f);
 
         l = fac.formattersForType(QStringLiteral("application/pgp-encrypted"));
-        QCOMPARE(l.size(), 6);
+        // shared-mime-info < 2.4 has application/pgp-encrytped as a subtype of text/plain, 2.4+ doesn't
+        // depending of that we get two additional entries for text/plain formatters here
+        QVERIFY(l.size() == 4 || l.size() == 6);
         QVERIFY(l.at(0) != application_octet_stream_f);
-        QCOMPARE(l.at(5), application_octet_stream_f);
+        QCOMPARE(l.at(l.size() - 1), application_octet_stream_f);
 
         l = fac.formattersForType(QStringLiteral("application/unknown"));
         QCOMPARE(l.size(), 3);
